@@ -1,6 +1,6 @@
 # Upload the files with scp in a batch.
 
-import os,sys,stat
+import os,sys,stat,dputhelper
 
 def upload(fqdn,login,incoming,files_to_upload,debug,compress):
 
@@ -24,12 +24,12 @@ def upload(fqdn,login,incoming,files_to_upload,debug,compress):
         print "D: Uploading with scp to %s@%s:%s" % \
             (login, fqdn, incoming)
         print "D: %s" % command
-    if os.spawnv(os.P_WAIT, '/usr/bin/scp', command):
+    if dputhelper.spawnv(os.P_WAIT, '/usr/bin/scp', command):
         print "Error while uploading."
         sys.exit(1)
     if change_mode:
         fix_command = ['ssh', '%s@%s' % (login, fqdn), 'chmod', '0644'] \
         + files_to_fix
-        if os.spawnv(os.P_WAIT, '/usr/bin/ssh', fix_command):
+        if dputhelper.spawnv(os.P_WAIT, '/usr/bin/ssh', fix_command):
             print "Error while fixing permission."
             sys.exit(1)
